<template>
  <div class="app-container">
    <div style="width: 100%">
      <el-card class="box-card" >
        <el-form :model="from" size="large" :inline="true" label-width="78px" @submit.native.prevent>
          <el-form-item label="曲轴码:" prop="scanObject1" >
            <el-input
              style="width: 350px"
              v-model="from.scanObject1"
              placeholder="请输曲轴码"
              clearable
              @keyup.enter.native="handleQuery"
              @input="handleQuery"
            />
          </el-form-item>
          <el-form-item label-width="200" label="托盘码" :prop="from.scanObject3"  style="align-content: center">
            <input v-model="from.scanObject3"
                   ref="inputdata2"
                   style="height: 39px; width: 300px"
                   placeholder="请输入托盘码"
            />
          </el-form-item>
          <el-form-item label-width="200" label="连杆码" :prop="from.scanObject2"  style="align-content: center">
            <input v-model="from.scanObject2"
                   ref="inputdata1"
                   style="height: 39px; width: 300px"
                   placeholder="请输入连杆码"
            />
          </el-form-item>
        </el-form>
        <el-form :model="from" ref="queryForm" :inline="true" >
          <el-form-item  label="机型:" prop="productSeries" >
            <el-select v-model="from.productSeries" placeholder="" clearable   style="width: 105px">
              <el-option

                v-for="dict in dict.type.productseries"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
          <el-form-item  label="瓦名称:" prop="tileName" >
            <el-select v-model="from.tileName" placeholder="" clearable style="width: 125px" >
              <el-option
                v-for="dict in dict.type.tilename"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
          <el-button type="primary" icon="el-icon-refresh" @click="handleQuery">查询</el-button>
        </el-form>
      </el-card>
      <el-col :span="24" >
        <el-card class="bottom-card">
          <div slot="header" class="clearfix">
            <i class="el-icon-tickets"></i>
            <span style="font-weight: bold">当前产品信息</span>
          </div>
          <el-descriptions :column="1"  :label-style="{'font-size': '20px'}" border  :content-style="{'min-width': '300px'}">
            <el-descriptions-item label="机型">
              <span>{{queryParams.productSeries}}</span>
            </el-descriptions-item>
            <el-descriptions-item label="发动机编号">
              <span>{{queryParams.sfcCode}}</span>
            </el-descriptions-item>
            <el-descriptions-item label="托盘码">
              <span>{{queryParams.scanObject3}}</span>
            </el-descriptions-item>
            <el-descriptions-item label="曲轴码">
              <span>{{queryParams.scanObject1}}</span>
            </el-descriptions-item>
            <el-descriptions-item label="连杆码">
              <span>{{queryParams.scanObject2}}</span>
            </el-descriptions-item>
            <el-descriptions-item label="瓦名称">
              <span>{{queryParams.tileName}}</span>
            </el-descriptions-item>
            <el-descriptions-item label="缸体编号">
              <span>{{queryParams.axisName}}</span>
            </el-descriptions-item>
            <el-descriptions-item label="配瓦颜色">
              <span  style="color: #FFFFFF;"  :style="{ backgroundColor: queryParams.tileColor }">{{queryParams.tileColor}}</span>
            </el-descriptions-item>
          </el-descriptions>
          <el-divider></el-divider>
        </el-card>
      </el-col>
    </div>
  </div>
</template>
<script>
import VueQr from 'vue-qr'
import {setBarcode} from "@/api/main/da/tileMatchMiddleware/tileMatchMiddleware";
import {listTileMatchRules, getTileMatchRules, delTileMatchRules, addTileMatchRules, updateTileMatchRules} from "@/api/main/bs/tileMatchRules/tileMatchRules";
export default {
  name: "index",
  dicts: ['colour_hex','productseries','axisname','neckname','tilename'],
  components: {
    VueQr,
  },
  data(){
    return{
      scannerFlag: false,
      loading: true,
      tileMatchKbList: [],
      qrCode: '',
      // 查询参数
      from:{
        pageNum: 1,
        pageSize: 10,
        productSeries:'380Y',
        scanObject1: null,
        scanObject2: null,
        scanObject3: null,
        axisName: null,
        neckName: null,
        tileName: '连杆瓦',
        axisParameterNoPosition: null,
        neckParameterPosition: null,
        axisValue: null,
        neckValue: null,
        tileColor: null,
        createUser: null,
        updateUser: null,
        state: null,
        weight: null,
      },
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        productSeries: null,
        scanObject1: null,
        scanObject2: null,
        scanObject3: null,
        axisName: null,
        neckName: null,
        tileName: null,
        axisParameterNoPosition: null,
        neckParameterPosition: null,
        axisValue: null,
        neckValue: null,
        tileColor: null,
        createUser: null,
        updateUser: null,
        state: null,
        weight: null,
        sfcCode:null,
      },
    }
  },
  mounted() {
    this.setFocus1()
    this.setFocus2()
    this.$refs.inputdata1.addEventListener('keydown',this.handleScannerInput1)
    this.$refs.inputdata2.addEventListener('keydown',this.handleScannerInput2)
  },
  beforeDestroy() {
    this.$refs.inputdata1.removeEventListener('keydown',this.handleScannerInput1)
    this.$refs.inputdata2.removeEventListener('keydown',this.handleScannerInput2)
  },
  methods:{
    refresh() {
      location.reload();
    },
    setFocus1(){
      this.$nextTick(()=>{
        this.$refs.inputdata1.focus()
      })
    },
    setFocus2(){
      this.$nextTick(()=>{
        this.$refs.inputdata2.focus()
      })
    },
    handleScannerInput1(event){
      if (this.scannerFlag){
        this.from.scanObject2 = ''
        this.$refs.inputdata1.value = ''
        this.scannerFlag = false
      }
      const input = event.target
      const inputValue = input.value
      this.from.scanObject2 = inputValue
      if (event.key === 'Enter'){
        this.scannerFlag = true
        //console.log('条码：',this.from.scanObject2)
        this.$refs.inputdata2.focus();
        //扫描完成
        if (typeof this.from.scanObject2 !== 'undefined') {
          setBarcode({barcode:this.from.scanObject2,locationCode:this.from.scanObject3}).then(res =>{
            console.log('res',res)
            this.queryParams.sfcCode=res.sfcCode;
            this.from.scanObject1=res.crankshaftNo;
            this.queryParams.axisName=res.cylinder;
            this.handleQuery()
            //this.from.scanObject2=this.from.scanObject2
            //this.queryParams.scanObject1=this.from.scanObject1
          })
        }
        this.handleQuery()
      }
    },
    handleScannerInput2(event){
      if (this.scannerFlag){
        this.from.scanObject3 = ''
        this.$refs.inputdata2.value = ''
        this.scannerFlag = false
      }
      const input = event.target
      const inputValue = input.value
      this.from.scanObject3= inputValue
      if (event.key === 'Enter'){
        this.scannerFlag = true
        console.log('条码2：',this.from.scanObject3)
        this.$refs.inputdata1.focus();
        this.from.scanObject2 = ''
        //扫描完成
      }
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.clear();

      if(this.from.scanObject3 !== null && this.from.scanObject2 !== null
        && this.from.productSeries !== null && this.from.productSeries !== "")
      {
        this.axisValueextracted();
        this.neckValueextracted();
        if(this.queryParams.axisValue !== null && this.queryParams.neckValue !== null){
          this.insetFromToQueryParams();
          this.getList();
        }
        else{
          const h = this.$createElement;
          this.$message({
            message: h('p',null, [
              h('span', null, '警告 '),
              h('i', { style: 'color: black' }, '箱体码或曲轴码输入有误'),
              h()]),
            type: 'error',
            center: true,
            offset:300
          });
        }
      }
      else{
        const h = this.$createElement;
        this.$message({
          message: h('p',null, [
            h('span', null, '警告 '),
            h('i', { style: 'color: black' }, '请填写所有搜索条件'),
            h()]),
          type: 'error',
          center: true,
          offset:300
        });
      }
    },

    // 取箱体码第三段为配瓦值
    axisValueextracted() {
      const parts1 = this.from.scanObject2.split(";");
      if (parts1.length >= 3) {
        //const axisValueextracted = parts1[2].substring(3,4);
        const axisValueextracted = parts1[2];
        return this.queryParams.axisValue= axisValueextracted;

      }
    },

    //取曲轴码第三段为配瓦值
    neckValueextracted() {
      const parts2 = this.from.scanObject1.split(";");
      if (parts2.length >= 3) {
        //const neckValueextracted = parts2[2].substring(3,4);
        const neckValueextracted = parts2[2];
        return this.queryParams.neckValue= neckValueextracted;
      }
    },
    //取配瓦颜色
    getList() {
      let queryParams = {
        productSeries : this.queryParams.productSeries,
        axisName : this.queryParams.axisName,
        // neckName : this.queryParams.neckName,
        tileName : this.queryParams.tileName,
        axisValue: this.queryParams.axisValue,
        neckValue: this.queryParams.neckValue,
      }
      console.log('参数：',queryParams)
      listTileMatchRules(queryParams).then(response => {
        this.queryParams.tileColor = response.rows[0].tileColor;
      });
    },
    clear(){
      this.queryParams.axisValue=null;
      this.queryParams.neckValue=null;
    },
    insetFromToQueryParams(){
      this.queryParams.productSeries=this.from.productSeries;
      //this.queryParams.axisName=this.from.axisName;
      this.queryParams.neckName=this.from.neckName;
      this.queryParams.tileName=this.from.tileName;
      this.queryParams.scanObject1=this.from.scanObject1;
      this.queryParams.scanObject2=this.from.scanObject2;
      this.queryParams.scanObject3=this.from.scanObject3;
    }

  },
}
</script>

<style scoped>
::v-deep .el-form-item__label{
  font-size: large;
}
::v-deep .el-card__body{
  padding: 15px 20px 0px 20px;
}
::v-deep .el-input .el-input--medium .el-input--suffix{
  width: 200px;
}

</style>
